==> stumpf-0.0.8.dev525.tar.gz: stumpf-0.0.8.dev525/stumpf/views/qualification_type.py <==
import boto3
from flask import Blueprint, current_app, jsonify, request
from flask_login import current_user

from stumpf.models import (CreateQualificationTypeSchema, db, QualificationType,
                           QualificationTypeSchema)


qualification_type_bp = Blueprint('qualification_type', __name__)
create_qualification_type_schema = CreateQualificationTypeSchema()
qualification_type_schema = QualificationTypeSchema()


@qualification_type_bp.route('/qualification-type', methods=['POST'])
def create_qualification_type():
    args = create_qualification_type_schema.load(request.json)

    if QualificationType.query.filter_by(name=args['name']).first():
        return jsonify({
            'error': 'Qualification type with that name already exists'
        }), 409

    if args['sandbox']:
        mturk = boto3.client('mturk',
                             endpoint_url=current_app.config['MTURK_SANDBOX_ENDPOINT_URL'])
    else:
        mturk = boto3.client('mturk',
                             endpoint_url=current_app.config['MTURK_PRODUCTION_ENDPOINT_URL'])

    try:
        qual_type = QualificationType(user=current_user, sandbox=args['sandbox'], name=args['name'],
                                      description=args['description'],
                                      keywords=args.get('keywords', ''), status=args['status'])
        db.session.add(qual_type)
        db.session.commit()

        mturk_qual_type = mturk. \
            create_qualification_type(Name=args['name'],
                                      Keywords=args.get('keywords', ''),
                                      Description=args['description'],
                                      QualificationTypeStatus=args['status'])

        qual_type.mturk_qt_id = mturk_qual_type['QualificationType']['QualificationTypeId']
        db.session.add(qual_type)
        db.session.commit()

        return jsonify(qualification_type_schema.dump(qual_type)), 201
    except Exception:
        db.session.rollback()
        raise

==> stumpf-0.1.13.dev2.tar.gz: stumpf-0.1.13.dev2/stumpf/views/qualification_type.py <==
import boto3
from flask import Blueprint, current_app, jsonify, request
from flask_login import current_user

from stumpf.decorators import handle_boto_client_errors
from stumpf.middleware import google_auth_middleware
from stumpf.models import (CreateQualificationTypeSchema, db, QualificationType,
                           QualificationTypeSchema)


qualification_type_bp = Blueprint('qualification_type', __name__)
qualification_type_bp.before_request(google_auth_middleware)

create_qualification_type_schema = CreateQualificationTypeSchema()
qualification_type_schema = QualificationTypeSchema()


@qualification_type_bp.route('/qualification-type', methods=['POST'])
@handle_boto_client_errors
def create_qualification_type():
    args = create_qualification_type_schema.load(request.json)

    if QualificationType.query.filter_by(name=args['name']).first():
        return jsonify({
            'error': 'Qualification type with that name already exists'
        }), 409

    session = boto3.session.Session()
    if args['sandbox']:
        mturk = session.client('mturk',
                               endpoint_url=current_app.config['MTURK_SANDBOX_ENDPOINT_URL'])
    else:
        mturk = session.client('mturk',
                               endpoint_url=current_app.config['MTURK_PRODUCTION_ENDPOINT_URL'])

    try:
        qual_type = QualificationType(user=current_user, sandbox=args['sandbox'], name=args['name'],
                                      description=args['description'],
                                      keywords=args.get('keywords', ''), status=args['status'])
        db.session.add(qual_type)
        db.session.commit()

        mturk_qual_type = mturk. \
            create_qualification_type(Name=args['name'],
                                      Keywords=args.get('keywords', ''),
                                      Description=args['description'],
                                      QualificationTypeStatus=args['status'])

        qual_type.mturk_qt_id = mturk_qual_type['QualificationType']['QualificationTypeId']
        db.session.add(qual_type)
        db.session.commit()

        return jsonify(qualification_type_schema.dump(qual_type)), 201
    except Exception:
        db.session.rollback()
        raise
